==> zygrib_3.5.0.orig.tar.gz: zygrib-3.5.0/src/MeteoTable.h <==
/**********************************************************************
zyGrib: meteorological GRIB file viewer
Copyright (C) 2008 - Jacques Zaninetti - http://www.zygrib.org

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
***********************************************************************/

#ifndef METEOTABLE_H
#define METEOTABLE_H

#include <QDialog>
#include <QFrame>
#include <QGridLayout>
#include <QLabel>
#include <QScrollArea>
#include <QPushButton>

#include "GribPlot.h"
#include "GribPointInfo.h"

#include "MeteotableOptionsDialog.h"

#define MTABLE_WIND_CELL 1
#define MTABLE_CLOUD_CELL 2


//===================================================================
class TableCell : public QWidget
{ Q_OBJECT
    public:
        TableCell(QWidget *parent, QString txt, bool bold,
        			QColor bgcolor);
		
		void setBorders(int num) { borders=num; }
		static const uint none  = 0;
		static const uint north = 1;
		static const uint west  = 2;
		static const uint south = 4;
		static const uint east  = 8;
		static const uint all   = 1+2+4+8;

    protected:
	    void  	paintEvent(QPaintEvent *event);
	    void    setContrastedTextColor(QColor bgColor);
	    
	    QColor  bgcolor, bordercolor;
	    QLabel  *label;
	    int     borders;
};

//===================================================================
class TableCell_Wind : public TableCell
{ Q_OBJECT
    public:
        TableCell_Wind(
        			double vx, double vy, bool south,
        			GribPlot *gribplot,
        			QWidget *parent, QString txt, bool bold,
        			QColor bgcolor
				);
    protected:
    	QColor    windArrowsColor;
    	double 	  vx, vy;
    	bool	  south;
    	bool	  showWindArrows;
    	GribPlot *gribplot;
	    void  	paintEvent(QPaintEvent *event);
};

//===================================================================
class TableCell_Clouds : public TableCell
{ Q_OBJECT
    public:
        TableCell_Clouds (
        			double val,
        			GribPlot *gribplot,
        			QWidget *parent, QString txt, bool bold,
        			QColor bgcolor
				);
    protected:
    	GribPlot *gribplot;
    	double   val;
	    void  	 paintEvent(QPaintEvent *event);
};

//===================================================================
// 
class MTGribData {
	public :
		MTGribData(QString codeStr, int pos) {
			this->codeStr = codeStr;
			this->pos = pos;
			this->gribCode = codeStr.toUInt(0, 16);
		}
		MTGribData(uint code, int pos) {
			this->codeStr = QString("%1").arg(code,8,16,QLatin1Char('0'));
			this->pos = pos;
			this->gribCode = codeStr.toUInt(0, 16);
		}
		QString codeStr;
		uint gribCode;
		int pos;
};

//===================================================================
class MeteoTableWidget : public QWidget
{ Q_OBJECT
    public:
        MeteoTableWidget(GribPlot *gribplot, double lon, double lat, QWidget *parent);
        ~MeteoTableWidget();
    
    private:
        double        lon, lat;
        GribPlot    *gribplot;
		QGridLayout *layout;
		
		std::list<GribPointInfo *> lspinfos;
		
		QList <MTGribData *> listVisibleData;
		
		void  createTable();
		void  createListVisibleGribData();
		
		void  addLine_Wind        (int lig);
		void  addLine_CloudCover  (int lig);
		void  addLine_Rain        (int lig);
		void  addLine_DewPoint    (int lig);
		void  addLine_Pressure    (int lig);
		void  addLine_HumidRel         (int lig);
		void  addLine_SnowDepth        (int lig);
		void  addLine_Isotherm0Height  (int lig);
		void  addLine_Temperature 	   (uchar type, int lig);
		void  addLine_DeltaTemperature (uchar type, int lig);
		void  addLine_Categorical 	   (uchar type, int lig);
		void  addLine_CAPEsfc     (int lig);

		void addCell_content( QString txt, 
				QGridLayout *layout,int lig,int col,
				int    rowspan=1,
				int    colspan=1,
				QColor bgcolor=Qt::white,
				int    cellType = 0,
				double  vx=0,
				double  vy=0
				);
				
		void addCell_title( QString txt, bool bold,
				QGridLayout *layout,int lig,int col,
				int rowspan=1, int colspan=1,
				bool isNowDate=false);
};


//===================================================================
// MeteoTable : dialog + MeteoTableWidget
//===================================================================
class MeteoTableDialog : public QDialog
{ Q_OBJECT
    public:
        MeteoTableDialog(GribPlot *gribplot, double lon, double lat, QString posName="");
        ~MeteoTableDialog();
    
    private:
    	GribPlot *gribplot;
    	double   lon, lat;
    	
		MeteoTableWidget 		*meteoTableWidget;
		DialogMeteotableOptions *optionsDialog;
		QScrollArea 			*scrollArea;
     	
     	QPushButton *btClose;
     	QPushButton *btOptions;
     	
		void closeEvent(QCloseEvent *) {delete this;};
	private slots :
		void slotBtOptions();
		void slotOptionsChanged();
		void reject()	{delete this;};
};


#endif

==> zygrib_3.9.2.orig.tar.gz: zygrib-3.9.2/src/MeteoTable.h <==
/**********************************************************************
zyGrib: meteorological GRIB file viewer
Copyright (C) 2008 - Jacques Zaninetti - http://www.zygrib.org

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.
***********************************************************************/

#ifndef METEOTABLE_H
#define METEOTABLE_H

#include <QDialog>
#include <QFrame>
#include <QScrollArea>
#include <QPushButton>

#include "MeteoTableWidget.h"
#include "MeteotableOptionsDialog.h"

//===================================================================
// MeteoTable : dialog + MeteoTableWidget
//===================================================================
class MeteoTableDialog : public QDialog
{ Q_OBJECT
    public:
        MeteoTableDialog (
					GriddedPlotter *plotter, 
					double lon, double lat, QString posName="");
        ~MeteoTableDialog();
		
		bool saveFileSYLK (QFile &file);
    
    private:
    	GriddedPlotter *plotter;
    	double   lon, lat;
    	QString  posName;
		
		MeteoTableWidget 		*meteoTableWidget;
		DialogMeteotableOptions *optionsDialog;
		QScrollArea 			*scrollArea;
     	
     	QPushButton *btClose;
     	QPushButton *btOptions;
		
     	QPushButton *btExport;
		void closeEvent(QCloseEvent *) {delete this;};
		
		bool SYLK_saveFile (QFile &file);
		int  SYLK_addData_gen  (QTextStream &out, int lig,int col, DataCode dtc);
		int  SYLK_addData_wind (QTextStream &out, int lig,int col, DataCode dtc);
		
	private slots :
		void slotBtOptions();
		void slotBtExport();
		void slotOptionsChanged();
		void reject()	{delete this;};
};


#endif
